@@ -36,6 +36,7 @@ import os
 import re
 import sys
 import shutil
+from distutils.version import LooseVersion
 
 import easybuild.tools.toolchain as toolchain
 from easybuild.framework.easyblock import EasyBlock
@@ -101,11 +102,15 @@ class EB_SCOTCH(EasyBlock):
         else:
             cflags += " -restrict -DIDXSIZE64"
 
-        if not self.toolchain.mpi_family() == toolchain.INTELMPI:  #@UndefinedVariable
+        if not self.toolchain.mpi_family() in [toolchain.INTELMPI, toolchain.QLOGICMPI]:  #@UndefinedVariable
             cflags += " -DSCOTCH_PTHREAD"
 
         # actually build
-        for app in ["scotch", "ptscotch"]:
+        apps = ['scotch', 'ptscotch']
+        if LooseVersion(self.version) >= LooseVersion('6.0'):
+            # separate target for esmumps in recent versions
+            apps.extend(['esmumps', 'ptesmumps'])
+        for app in apps:
             cmd = 'make CCS="%s" CCP="%s" CCD="%s" CFLAGS="%s" %s' % (ccs, ccp, ccd, cflags, app)
             run_cmd(cmd, log_all=True, simple=True)
 
